Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/games/wump Fix dog-Latin. The plural of wumpus could be wump...



details:   https://anonhg.NetBSD.org/src/rev/123c3c783adb
branches:  trunk
changeset: 755248:123c3c783adb
user:      dholland <dholland%NetBSD.org@localhost>
date:      Sat May 29 22:53:49 2010 +0000

description:
Fix dog-Latin. The plural of wumpus could be wumpi, wumpus, or even wumpora,
but not 'wumpii'. Where does this -ii crap come from?

diffstat:

 games/wump/wump.c |  10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)

diffs (45 lines):

diff -r 92f2cf39c192 -r 123c3c783adb games/wump/wump.c
--- a/games/wump/wump.c Sat May 29 22:48:57 2010 +0000
+++ b/games/wump/wump.c Sat May 29 22:53:49 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: wump.c,v 1.25 2009/08/27 00:19:52 dholland Exp $       */
+/*     $NetBSD: wump.c,v 1.26 2010/05/29 22:53:49 dholland Exp $       */
 
 /*
  * Copyright (c) 1989, 1993
@@ -43,7 +43,7 @@
 #if 0
 static char sccsid[] = "@(#)wump.c     8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: wump.c,v 1.25 2009/08/27 00:19:52 dholland Exp $");
+__RCSID("$NetBSD: wump.c,v 1.26 2010/05/29 22:53:49 dholland Exp $");
 #endif
 #endif /* not lint */
 
@@ -179,7 +179,7 @@
                        }
                        if (room_num > MAX_ROOMS_IN_CAVE) {
                                (void)fprintf(stderr,
-       "Even wumpii can't furnish caves that large!\n");
+       "Even wumpi can't furnish caves that large!\n");
                                exit(1);
                        }
                        break;
@@ -187,7 +187,7 @@
                        link_num = atoi(optarg);
                        if (link_num < 2) {
                                (void)fprintf(stderr,
-       "Wumpii like extra doors in their caves!\n");
+       "Wumpi like extra doors in their caves!\n");
                                exit(1);
                        }
                        break;
@@ -261,7 +261,7 @@
 
        /*
         * Routine will explain what's going on with the current room, as well
         * as describe whether there are pits, bats, & wumpii nearby.  It's
         * all pretty mindless, really.
         */
        (void)printf(
@@ -261,7 +261,7 @@
        /*
         * Routine will explain what's going on with the current room, as well
-        * as describe whether there are pits, bats, & wumpii nearby.  It's
+        * as describe whether there are pits, bats, & wumpi nearby.  It's
         * all pretty mindless, really.
         */



Home | Main Index | Thread Index | Old Index